@@ -41,6 +41,11 @@ class DescribeDomainUsageDataRequest(RpcRequest):
 
 	def set_Type(self, Type):  # String
 		self.add_query_param('Type', Type)
+	def get_DataProtocol(self): # String
+		return self.get_query_params().get('DataProtocol')
+
+	def set_DataProtocol(self, DataProtocol):  # String
+		self.add_query_param('DataProtocol', DataProtocol)
 	def get_Area(self): # String
 		return self.get_query_params().get('Area')
 
